__code__='Gas1]gMYJ*&Daab$RN/o.")2#gk:f/HD<e4+Wr?B.1I"@"<!<_GdjeZa#:Q!2RU\\+qT=T_97GtUG[eZaBXl(8U[cXRR@VkJIj7n,H!!jMaUiu.EQAO)-mNAXOeLo6:5?c]K4eG!)Uk+j$EV<@XNW<$)0V-BfHiH!k#dnnJ!iCFLLc$b>kjsPL/[#!::\\1K6_0B9)]eM+G[Fi9G57(V-+;/Iem_*1rq\'([a\\`fS30\\!md@_a!5,4.`-mTN1"_Z$1a#V.a2)&qh>G.m9OaP^p3@1RadtYG=;)Gb)4GqQ^[D^A(FJoWtKgpXFBVcO$>LM>VrN`i;\\ab\'fd^.@C=.W;6/\'5%n844"<bK(+6_qg8@RGO-SNn03(&lFDKh^oH2JJ-hQ<I;ts?)gQVf>h+g^\'[20ms!fRfuZg_,me`<0os[:Xh^,=*BQhDg4C5Sf8[EaGMR)TFaGk/LM0aopJ]rW7ijAeWHmGO\\:B+=U`hfdRAO3NCS&I228-0\'h0d[0")3\'n)#-4VS=,36IUAN5mSquU;TZh&rV60?(AVS+F_sA2fk+u;*dM2O;aDCkYqYtr#mAWMEH:V##M+M%4,m?uI\\J/(ruGfK,6&O#j0qdD\\<(qF(!!305d)<oqU>Pd9RdVU1u_&Od.Os4c6(;7^hY9FiU;,VgWo0.dde%Kf9bs0XfjoZCZi5],K3+4L$@utLO83k=Ka`&glpmQ9WS.VpCDmiDfR@BD/qe\'$b[k8KqDG$dH7SJKUekpPMQ!fXgP^s(P+V%hZe(fpMA)7qU9U,T[e,mJ.X\\[gd9e2U2q8]X+g$I2E0MN^hf[A\\I%`L`cEtD+kPJ@;T7$5:*b#s?uSi&",b8$N:J/B(E\\H+"6Gk2,D"fEk>R4YblV7goV-:.%]DfP3r!QFZ_Eqim4+DVo"l+kWi1B)k"Jf9/%Mf!L-V"[)p"K`!l]LAUPB^M&u`#sl#/&nb)]$\'HAq+Z/q-IWCp?M?Wr;*`d&PUBIK151>ak~>'



__code__='Gas1];/[+<&>$Qs4,unKR$<mPaq[Ol<U)RUMQ3\\VMN"MY3GsM$+OfUt\\_/5uc?I=c3cRpR.7emO+6h\\Hca_U+M`u:GiZg\'TZ$/_(h3m`$)=P%a_qaE9c(AZ]J!%R:0EV"e"X(T"@!c_*8:VCn%(qu,%ak?Q@00V_28D92!al+L&[2Rd%WDaD"2OMY(B@Zi(BN9@QN3?Q56SV-p^uH)J6)_8!W3Z$.c<2"cN(-^bCu90F$9Hg.f;oo(5uuNl^WO55h=lG"S(affR.,D$Y$RG5Nc!9Pf!qI3aWS11RKiBX:"#\\AQ]/$251GrXH#4@7OJ-T3gLE>2$hE/YVhnU#$Bmq#riQ:q6^MIi/!-0+I#gU""gMnZcl;dE+D61TQ1e&b[U[*pk`aITCZr3hT"T`_3<`n7o(,2=P/bif3/msfkaMY<>]Ml.]c<5gP(FkF.DWVN32kN:^p%\\+%Jb?Wg3V/WdE&t?0PlLkfgIr\'-0PFB<mdjkba,hOeuAc`c3,iU+KOm[l3&!-%^m7`Vrtc?IADXEIsC1f1V_0C>q`2-`TaX-0q((AA_\\/(n/^4(mtnh_gL9h/CR#O^;"5toUcW\\0XH0h$3M/Y\'(&X18YGH]Hd6P2lh(\'LkMY:6<TRiRDn/.hG&>)9oQ.LNmme$uLIl;0b*LL5<.ku3l/@,CR#lnN$L6f`]89FL<*/-nqfd+nnitTA4hpefJbr>VS=*+b>=kR;-a)e6r5N"$1Xu.aWPXYmDE!E[:OP5d^AVA"*29[dM$eG)9Y(qJ4rBj*]5hP<`r/!VhRgQ!*H+-dgSZH8Z\'Hm5,>+p/]UOBgNqqb#L6LiIqVu5^Ce6>:IbkETAZuuj4&lN"]ALfd<BmPaiDrG3rU-G.q/*#id,+K680S<;OuKG:A<63$Zb/Gc_*j"Rd!c`W;;%\\Q$Kd7HY6=\'PR=<+qH7?uAi\\^^oN,5=\\<gZ/`6k_IOQ&3=NdsSnb$oHdL(:<(ZlA.c#hmpluh(\'dqN<u^BKpGOeIMEi"+utWl_=RRQ,,c.-@bd[nC,sQHYuca0`A/rrr_G+7j+e:rrQ*sNf3G&[<*p>tU41,VMQn_t`kSncA?Z~>'
